@@ -19,7 +19,7 @@ function(api_key, id, language=NA, append_to_response=NA, include_image_language
     l <- l[!is.na(l)]
     
     if(length(l)>0){
-        params <- paste("&", names(l), "=",l, sep="", collapse="")
+        params <- paste("&", names(l), "=", stri_join_list(l, sep = ","), sep = "", collapse = "")
         url <- fromJSON(GET(url=paste("http://api.themoviedb.org/3/collection/", id, "/images?api_key=", 
                                       api_key, params, sep=""))$url)   
     } else{
