@@ -9,7 +9,7 @@ function(api_key, id, season_number, episode_number, language=NA){
     l <- l[!is.na(l)]
     
     if(length(l)>0){
-        params <- paste("&", names(l), "=",l, sep="", collapse="")
+        params <- paste("&", names(l), "=", stri_join_list(l, sep = ","), sep = "", collapse = "")
         url <- fromJSON(GET(url=paste("http://api.themoviedb.org/3/tv/", id, "/season/", season_number, 
                                       "/episode/", episode_number, "/external_ids?api_key=", 
                                       api_key, params, sep=""))$url)
