@@ -15,7 +15,7 @@ function(api_key, id, language=NA, include_image_language=NA){
     l <- l[!is.na(l)]
     
     if(length(l)>0){
-        params <- paste("&", names(l), "=",l, sep="", collapse="")
+        params <- paste("&", names(l), "=", stri_join_list(l, sep = ","), sep = "", collapse = "")
         url <- fromJSON(GET(url=paste("http://api.themoviedb.org/3/tv/", id, "/images?api_key=",
                                       api_key, params, sep=""))$url)
     } else{
