@@ -19,7 +19,7 @@ function(api_key, id, season_number, language=NA, append_to_response=NA){
     l <- l[!is.na(l)]
     
     if(length(l)>0){
-        params <- paste("&", names(l), "=",l, sep="", collapse="")
+        params <- paste("&", names(l), "=", stri_join_list(l, sep = ","), sep = "", collapse = "")
         url <- fromJSON(GET(url=paste("http://api.themoviedb.org/3/tv/", id, "/season/", season_number,"?api_key=", api_key, params, sep=""))$url)
     } else{
         url <- fromJSON(GET(url=paste("http://api.themoviedb.org/3/tv/", id, "/season/", season_number,"?api_key=", api_key, sep=""))$url)
